---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Platform/Versions**

OS:
Python version:
MMU version:

**Description**
A clear and concise description of what the bug is.

**MRE**

Minimal reproducible example:

```python
import mmu
```
